@@ -60,6 +60,10 @@ Display version information.
 
 Prepare a new tree named I<DIST>
 
+=item B<apt> I<DIST> <B<update>|B<source>|B<show>|B<showsrc>|...>
+
+Run B<apt> inside I<DIST>
+
 =item B<apt-get> I<DIST> <B<update>|B<source>|...>
 
 Run B<apt-get> inside I<DIST>
@@ -68,6 +72,10 @@ Run B<apt-get> inside I<DIST>
 
 Run B<apt-cache> inside I<DIST>
 
+=item B<apt-file> I<DIST> <B<update>|B<search>|...>
+
+Run B<apt-file> inside I<DIST>
+
 =item B<apt-rdepends> I<DIST> [...]
 
 Run B<apt-rdepends> inside I<DIST>
@@ -264,6 +272,38 @@ sub aptcmd
     exec($cmd, @args);
 }
 
+sub apt_file
+{
+    my ($dist, @args) = @_;
+    dist_check($dist);
+    aptconfig($dist);
+    my @query = ('dpkg-query', '-W', '-f');
+    open(my $fd, '-|', @query, '${Version}', 'apt-file')
+	or fatal('Unable to run dpkg-query.');
+    my $aptfile_version = <$fd>;
+    close($fd);
+    if (version_compare('3.0~', $aptfile_version) < 0) {
+	open($fd, '-|', @query, '${Conffiles}\n', 'apt-file')
+	    or fatal('Unable to run dpkg-query.');
+	my @aptfile_confs = map { (split)[0] }
+			    grep { /apt\.conf\.d/ } <$fd>;
+	close($fd);
+	# New-style apt-file
+	for my $conffile (@aptfile_confs) {
+	    if (! -f "$datadir/$dist/$conffile") {
+		cp($conffile, "$datadir/$dist/$conffile");
+	    }
+	}
+    }
+    else {
+	my $cache_directory = $datadir . '/' . $dist . "/var/cache/apt/apt-file";
+	unshift(@args,
+	    '--cache', $cache_directory
+	);
+    }
+    exec('apt-file', @args);
+}
+
 sub bin2src
 {
     my ($dist, $pkg) = @_;
@@ -383,10 +423,13 @@ EOF
 			    debian-archive-removed-keys.gpg
 			    ubuntu-archive-keyring.gpg
 			    ubuntu-archive-removed-keys.gpg)) {
-	cp("/usr/share/keyrings/$keyring", "$dir/etc/apt/trusted.gpg.d/");
+	my $src = "/usr/share/keyrings/$keyring";
+	if (-f $src) {
+	    symlink $src, "$dir/etc/apt/trusted.gpg.d/$keyring";
+	}
     }
     print "Now edit $dir/etc/apt/sources.list\n" unless $version;
-    print "Run chdist apt-get $dist update\n";
+    print "Run chdist apt $dist update\n";
     print "And enjoy.\n";
 }
 
@@ -660,12 +703,18 @@ given ($command) {
     when ('create') {
 	dist_create(@ARGV);
     }
+    when ('apt') {
+	aptcmd('apt', @ARGV);
+    }
     when ('apt-get') {
 	aptcmd('apt-get', @ARGV);
     }
     when ('apt-cache') {
 	aptcmd('apt-cache', @ARGV);
     }
+    when ('apt-file') {
+	apt_file(@ARGV);
+    }
     when ('apt-rdepends') {
 	aptcmd('apt-rdepends', @ARGV);
     }
